@@ -7,6 +7,7 @@
 #' @param allAdj list of adjacency matrices
 #' @param nbClusters number of clusters to be found
 #' @param nbCores number of cores for parallelization. Default: detectCores().
+#' @param sig parameter for Gaussian kernel used for the similarity matrix
 #'
 #' @return list with the obtained graph clusteirng ($clust) and the matrix with the
 #' pairwise graphon distances between all pairs of networks
@@ -16,7 +17,7 @@
 #' theta <- list(pi=c(.5,.5), gamma=matrix((1:4)/8,2,2))
 #' obs <- rCollectSBM(rep(10,4), theta)$listGraphs
 #' res <- graphonSpectralClustering(obs, 2, nbCores=1)
-graphonSpectralClustering <- function(allAdj, nbClusters, nbCores=detectCores()){
+graphonSpectralClustering <- function(allAdj, nbClusters, sig=.1, nbCores=detectCores()){
   M <- length(allAdj)
   message("initialization of individual SBMs...\n")
   listTheta <- fitSimpleSBM(allAdj, nbCores = nbCores, outCountStat = FALSE)
@@ -28,7 +29,9 @@ graphonSpectralClustering <- function(allAdj, nbClusters, nbCores=detectCores())
       graphonDist[k, l] <- graphonDist[l, k] <- sbmNorm(listTheta[[k]], listTheta[[l]])
     }
   }
-  clustering <- spectralPAM(graphonDist, K = nbClusters, flagDiagZero = TRUE)$cluster
+
+  simMat <- exp(-graphonDist^2/sig^2)
+  clustering <- spectralPAM(simMat, K = nbClusters, flagDiagZero = TRUE)$cluster
 
   return(list(clust=clustering, graphonDist=graphonDist))
 }
@@ -36,4 +39,3 @@ graphonSpectralClustering <- function(allAdj, nbClusters, nbCores=detectCores())
 
 
 
-
